@@ -1278,16 +1278,18 @@ class StageBase(TargetBase, ClearBase, GenBase):
                                 self.settings["binrepos_conf"])
             Path(binrpath).mkdir(mode=0o755, parents=True, exist_ok=True)
 
-            binrfile = binrpath + "/gentoobinhost.conf"
+            binrfile = binrpath + "/gentoo.conf"
             with open(binrfile, "w") as myb:
                 log.notice("Writing the stage binrepo config to: %s" % binrfile)
                 myb.write("# These settings were set by the catalyst build script "
                         "that automatically\n# built this stage.\n")
                 myb.write("# Please consider using a local mirror.\n\n")
-                myb.write("[gentoobinhost]\n")
+                myb.write("[gentoo]\n")
                 myb.write("priority = 1\n")
                 myb.write("sync-uri = " + self.settings["binhost"] + \
                         self.settings["binrepo_path"] + "\n")
+                myb.write("location = /var/cache/binhost/gentoo\n")
+                myb.write("verify-signature = true\n")
 
     def fsscript(self):
         if "autoresume" in self.settings["options"] \
