@@ -21,6 +21,7 @@ valid_config_file_values = frozenset([
     "options",
     "port_logdir",
     "repo_basedir",
+    "repo_openpgp_key_path",
     "repo_name",
     "repos_storedir",
     "sharedir",
@@ -51,6 +52,7 @@ confdefaults = {
     "pkgdir": "/var/cache/binpkgs",
     "port_tmpdir": "/var/tmp/portage",
     "repo_basedir": "/var/db/repos",
+    "repo_openpgp_key_path": "/usr/share/openpgp-keys/gentoo-release.asc",
     "repo_name": "gentoo",
     "repos_storedir": "%(storedir)s/repos",
     "sharedir": "/usr/share/catalyst",
